==> open-xchange-messaging-facebook_6.16.1.0.orig.tar.gz: open-xchange-messaging-facebook-6.16.1.0/src/com/openexchange/messaging/facebook/FacebookMessagingAccountAccess.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.facebook;

import com.google.code.facebookapi.IFacebookRestClient;
import com.openexchange.messaging.MessagingAccount;
import com.openexchange.messaging.MessagingAccountAccess;
import com.openexchange.messaging.MessagingException;
import com.openexchange.messaging.MessagingExceptionCodes;
import com.openexchange.messaging.MessagingFolder;
import com.openexchange.messaging.MessagingFolderAccess;
import com.openexchange.messaging.MessagingMessageAccess;
import com.openexchange.session.Session;

/**
 * {@link FacebookMessagingAccountAccess}
 * 
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since Open-Xchange v6.16
 */
public final class FacebookMessagingAccountAccess extends FacebookMessagingResource implements MessagingAccountAccess {

    /**
     * The folder access.
     */
    private volatile FacebookMessagingFolderAccess folderAccess;

    /**
     * The message access.
     */
    private volatile FacebookMessagingMessageAccess messageAccess;

    /**
     * Initializes a new {@link FacebookMessagingAccountAccess}.
     * 
     * @param messagingAccount The facebook account
     * @param session The session
     */
    public FacebookMessagingAccountAccess(final MessagingAccount messagingAccount, final Session session) {
        super(messagingAccount, session);
    }

    /**
     * Initializes a new {@link FacebookMessagingAccountAccess} for test purpose.
     * 
     * @param login The facebook login
     * @param password The facebook password
     * @param apiKey The API key
     * @param secretKey The secret key
     */
    public FacebookMessagingAccountAccess(final String login, final String password, final String apiKey, final String secretKey) {
        super(login, password, apiKey, secretKey);
    }

    /**
     * Gets the facebook REST client.
     * 
     * @return The facebook REST client
     */
    public IFacebookRestClient<Object> getFacebookRestClient() {
        return facebookSession.getFacebookRestClient();
    }

    public int getAccountId() {
        return messagingAccount.getId();
    }

    public MessagingFolderAccess getFolderAccess() throws MessagingException {
        if (!facebookSession.isConnected()) {
            throw MessagingExceptionCodes.NOT_CONNECTED.create();
        }
        FacebookMessagingFolderAccess tmp = folderAccess;
        if (null == tmp) {
            folderAccess =
                tmp =
                    new FacebookMessagingFolderAccess(
                        facebookSession.getFacebookRestClient(),
                        messagingAccount,
                        session,
                        facebookSession.getFacebookUserId(),
                        facebookSession.getFacebookSession());
        }
        return tmp;
    }

    public MessagingMessageAccess getMessageAccess() throws MessagingException {
        if (!facebookSession.isConnected()) {
            throw MessagingExceptionCodes.NOT_CONNECTED.create();
        }
        FacebookMessagingMessageAccess tmp = messageAccess;
        if (null == tmp) {
            messageAccess =
                tmp =
                    new FacebookMessagingMessageAccess(
                        facebookSession.getFacebookRestClient(),
                        messagingAccount,
                        session,
                        facebookSession.getFacebookUserId(),
                        facebookSession.getFacebookSession());
        }
        return tmp;
    }

    public MessagingFolder getRootFolder() throws MessagingException {
        connect();
        return getFolderAccess().getRootFolder();
    }

}

==> open-xchange-messaging-facebook_6.20.8.0.orig.tar.gz: open-xchange-messaging-facebook-6.20.8.0/src/com/openexchange/messaging/facebook/FacebookMessagingAccountAccess.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.facebook;

import com.openexchange.messaging.MessagingAccount;
import com.openexchange.messaging.MessagingAccountAccess;
import com.openexchange.messaging.MessagingException;
import com.openexchange.messaging.MessagingFolder;
import com.openexchange.messaging.MessagingFolderAccess;
import com.openexchange.messaging.MessagingMessageAccess;
import com.openexchange.session.Session;

/**
 * {@link FacebookMessagingAccountAccess}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since Open-Xchange v6.16
 */
public final class FacebookMessagingAccountAccess extends FacebookMessagingResource implements MessagingAccountAccess {

    /**
     * The folder access.
     */
    private volatile FacebookMessagingFolderAccess folderAccess;

    /**
     * The message access.
     */
    private volatile FacebookMessagingMessageAccess messageAccess;

    /**
     * Initializes a new {@link FacebookMessagingAccountAccess}.
     *
     * @param messagingAccount The facebook account
     * @param session The session
     * @throws FacebookMessagingException If initialization fails
     */
    public FacebookMessagingAccountAccess(final MessagingAccount messagingAccount, final Session session) throws FacebookMessagingException {
        super(messagingAccount, session);
    }

    public int getAccountId() {
        return messagingAccount.getId();
    }

    public MessagingFolderAccess getFolderAccess() throws MessagingException {
        FacebookMessagingFolderAccess tmp = folderAccess;
        if (null == tmp) {
            folderAccess = tmp = new FacebookMessagingFolderAccess(facebookOAuthInfo, messagingAccount, session);
        }
        return tmp;
    }

    public MessagingMessageAccess getMessageAccess() throws MessagingException {
        FacebookMessagingMessageAccess tmp = messageAccess;
        if (null == tmp) {
            messageAccess = tmp = new FacebookMessagingMessageAccess(facebookOAuthInfo, messagingAccount, session);
        }
        return tmp;
    }

    public MessagingFolder getRootFolder() throws MessagingException {
        connect();
        return getFolderAccess().getRootFolder();
    }

}
